function [d]=kldisc(P1, P2, whichlog)
% function [d]=kldisc(P1, P2, whichlog) calculates the Kulback Leibler divergence 
% between discrete Probability densities P1 and P2.
% The measure calculates d=sum_k P1(k) log(P1(k)/P2(k)).
% Note: Potential Warning messages should be ignored, they 
% are taken care of by the algorithm.
%
% inputs: 
% P1 [nr samples x nr events] : each row specifies a distribution over 
% a discrete event set.
% P2 [nr samples x nr events] : each row specifies a distribution over 
% a discrete event set.
% whichlog: '2' - log 2 based (bit) 'e' - log e based (nat). 
%
% output:
% d [nr. samples x 1]: distances between P1 and P2 calculated as described above.
%
% (C) P. Sykacek 2002

if nargin == 2 
    whichlog='2';
end
if whichlog=='2'
    Plg=log2(P1./P2);
else
    Plg=log(P1./P2);
end
% the special cases follow from del'Hospital.
% if both probs are 0
id=find(isnan(Plg));
Plg(id)=0;
% if Plg is -infinity we can set it to 0 since lim x-> 0 x*log(x) is 0.
id=find(isinf(Plg)&sign(Plg)==-1);
Plg(id)=0;
d=sum(P1.*Plg,2);
